/*******************************************************************************
* File Name: main.c
*
* Version: 1.0
*
* Description:
*  This example project demonstrates the use of an SCB-based SPI master
*  component. The SCB SPI master communicates with a UDB-based SPI slave,
*  located on the same PSoC but wired together externally. The SPI slave
*  receives a packet with a command from the SPI master to control the
*  RGB LED color. Once the slave updates the LED color, it returns a status
*  packet to the master.
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation. All rights reserved.
* This software is owned by Cypress Semiconductor Corporation and is protected
* by and subject to worldwide patent and copyright laws and treaties.
* Therefore, you may use this software only as provided in the license agreement
* accompanying the software package from which you obtained this software.
* CYPRESS AND ITS SUPPLIERS MAKE NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
* WITH REGARD TO THIS SOFTWARE, INCLUDING, BUT NOT LIMITED TO, NONINFRINGEMENT,
* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
*******************************************************************************/

#include <main.h>

/* SPIM functions */
static void SPIM_SendCommandPacket(uint32 cmd);
static void SPIM_SendDataPacket(uint32 data);
static void SPIM_SendDataPackets(void);

static uint8 spi_done = 0;

void Master_ISR()
{
    /* This clears the interrupt source */
    SPIM_ClearMasterInterruptSource(SPIM_INTR_MASTER_SPI_DONE);
    
    spi_done = 1;
}

/*******************************************************************************
* Function Name: main
********************************************************************************
* Summary:
*  The main function performs the following actions:
*   1. Turns off RGB LED.
*   2. Sets up SPIS and SPIM components.
*   3. Enables global interrupts.
*   4. SPI master (SPIM) sends command to the SPI slave (SPIS) to control
*      RGB LED.
*   5. SPIS receives the command, updates the LED and returns a status packet.
*   6. SPIM receives the response status packet. If successful, increment to
*      next command. Otherwise send the same command until successful.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
int main()
{
    uint32 cmd;
    uint32 data;

    /* Start SPIS and SPIM components operation */
    SPIM_Start();
    SPIM_SetCustomInterruptHandler(*Master_ISR);
    SPIM_SetMasterInterruptMode(SPIM_INTR_MASTER_SPI_DONE);
    SPIM_SpiSetActiveSlaveSelect(SPIM_SPI_SLAVE_SELECT0);

    CyGlobalIntEnable;

    /* Set command to start with */

    /* Put data into the slave TX buffer to be transferred while following
    * master access.
    */
    for(;;)
    {
        cmd = 0x01;
        SPIM_SendCommandPacket(cmd);
        data = 0x03;
        SPIM_SendDataPacket(data);
        data = 0x00;
        SPIM_SendDataPacket(data);
        data = 0x2B;
        SPIM_SendDataPacket(data);
        data = 0x2B;
        SPIM_SendDataPacket(data);
        data = 0x09;
        SPIM_SendDataPacket(data);
        
        CyDelayUs(10);
        
        cmd = 0x06;
        SPIM_SendCommandPacket(cmd);
        SPIM_SendDataPackets();
        CyDelay(1);
    }
}


/*******************************************************************************
* Function Name: SPIM_SendCommandPacket
*******************************************************************************/
static void SPIM_SendCommandPacket(uint32 cmd)
{
    CD_Write(0);

    /* Start transfer */
    SPIM_SpiUartWriteTxData(cmd);

    while (spi_done == 0);
    spi_done = 0;
    
    /* Clear dummy bytes from RX buffer */
    SPIM_SpiUartClearRxBuffer();
}

static void SPIM_SendDataPacket(uint32 data)
{
    CD_Write(1);

    /* Start transfer */
    SPIM_SpiUartWriteTxData(data);

    while (spi_done == 0);
    spi_done = 0;
    
    /* Clear dummy bytes from RX buffer */
    SPIM_SpiUartClearRxBuffer();
}

static void SPIM_SendDataPackets(void)
{
    CD_Write(1);

    static uint8 mTxBuffer[3] = {0x07, 0x07, 0x17};
    
    /* Start transfer */
    SPIM_SpiUartPutArray(mTxBuffer, 3);

    while (spi_done == 0);
    spi_done = 0;
    
    /* Clear dummy bytes from RX buffer */
    SPIM_SpiUartClearRxBuffer();
}

/* [] END OF FILE */
